==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/FunctionMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_SYNCSetImpl;
import io.ciera.tool.sql.ooaofooa.message.FunctionMessage;
import io.ciera.tool.sql.ooaofooa.message.FunctionMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.SynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.List;


public class FunctionMessageSetImpl extends InstanceSet<FunctionMessageSet,FunctionMessage> implements FunctionMessageSet {

    // attributes
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( FunctionMessage functionmessage : this ) functionmessage.setSync_ID( ref_Sync_ID );
    }
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( FunctionMessage functionmessage : this ) functionmessage.setMsg_ID( ref_Msg_ID );
    }


    // selections
    @Override
    public S_SYNCSet R1010_is_invocation_of_S_SYNC() throws XtumlException {
        S_SYNCSet s_syncset = new S_SYNCSetImpl();
        for ( FunctionMessage functionmessage : this ) s_syncset.add( functionmessage.R1010_is_invocation_of_S_SYNC() );
        return s_syncset;
    }
    @Override
    public SynchronousMessageSet R1020_is_a_SynchronousMessage() throws XtumlException {
        SynchronousMessageSet synchronousmessageset = new SynchronousMessageSetImpl();
        for ( FunctionMessage functionmessage : this ) synchronousmessageset.add( functionmessage.R1020_is_a_SynchronousMessage() );
        return synchronousmessageset;
    }


    @Override
    public FunctionMessage nullElement() {
        return FunctionMessageImpl.EMPTY_FUNCTIONMESSAGE;
    }

    @Override
    public FunctionMessageSet emptySet() {
      return new FunctionMessageSetImpl();
    }

    @Override
    public FunctionMessageSet value() {
        return this;
    }

    @Override
    public List<FunctionMessage> elements() {
        return Arrays.asList(toArray(new FunctionMessage[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/FunctionMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_SYNCSetImpl;
import io.ciera.tool.sql.ooaofooa.message.FunctionMessage;
import io.ciera.tool.sql.ooaofooa.message.FunctionMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.SynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class FunctionMessageSetImpl extends InstanceSet<FunctionMessageSet,FunctionMessage> implements FunctionMessageSet {

    public FunctionMessageSetImpl() {
    }

    public FunctionMessageSetImpl(Comparator<? super FunctionMessage> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( FunctionMessage functionmessage : this ) functionmessage.setSync_ID( ref_Sync_ID );
    }
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( FunctionMessage functionmessage : this ) functionmessage.setMsg_ID( ref_Msg_ID );
    }


    // selections
    @Override
    public S_SYNCSet R1010_is_invocation_of_S_SYNC() throws XtumlException {
        S_SYNCSet s_syncset = new S_SYNCSetImpl();
        for ( FunctionMessage functionmessage : this ) s_syncset.add( functionmessage.R1010_is_invocation_of_S_SYNC() );
        return s_syncset;
    }
    @Override
    public SynchronousMessageSet R1020_is_a_SynchronousMessage() throws XtumlException {
        SynchronousMessageSet synchronousmessageset = new SynchronousMessageSetImpl();
        for ( FunctionMessage functionmessage : this ) synchronousmessageset.add( functionmessage.R1020_is_a_SynchronousMessage() );
        return synchronousmessageset;
    }


    @Override
    public FunctionMessage nullElement() {
        return FunctionMessageImpl.EMPTY_FUNCTIONMESSAGE;
    }

    @Override
    public FunctionMessageSet emptySet() {
      return new FunctionMessageSetImpl();
    }

    @Override
    public FunctionMessageSet emptySet(Comparator<? super FunctionMessage> comp) {
      return new FunctionMessageSetImpl(comp);
    }

    @Override
    public FunctionMessageSet value() {
        return this;
    }

    @Override
    public List<FunctionMessage> elements() {
        return Arrays.asList(toArray(new FunctionMessage[0]));
    }

}
